@@ -83,21 +83,20 @@
 #'     scale_x_continuous scale_y_continuous Stat StatIdentity theme theme_grey
 #'     %+replace%
 #' @importFrom mirai mirai
-#' @importFrom nanonext ncurl sha256 strcat
+#' @importFrom nanonext ncurl strcat
+#' @importFrom secretbase sha3
+#' @importFrom RcppSimdJson is_valid_json
 #' @importFrom shiny checkboxInput column downloadButton downloadHandler HTML
 #'     fillPage fluidPage fluidRow hoverOpts invalidateLater isolate
 #'     numericInput observeEvent plotOutput reactive reactiveVal renderPlot
 #'     renderUI req runApp selectInput shinyApp sliderInput stopApp tags
 #'     textInput uiOutput wellPanel
-#' @importFrom RcppSimdJson is_valid_json
 #' @importFrom stats na.omit sd
 #' @importFrom utils packageVersion str
 #' @importFrom xts endpoints
 #' @importFrom zoo coredata index
 #'
-#' @docType package
-#' @name ichimoku-package
-NULL
+"_PACKAGE"
 
 .onLoad <- function(libname, pkgname) {
   do_ <- do_()
@@ -117,5 +116,5 @@ NULL
     if (i %in% c(1:3, 11:13)) Sys.sleep(0.03) else Sys.sleep(0.08)
   }
   cat("\n")
-  invisible(substitute())
+  invisible(quote(expr=))
 }
